/*
	Description: Creates Appendix Table 1 (summary statistics for industry-level control variables)

	Author: Brendan Price
	Updated: July 30, 2014
*/

version 12.1
set more off
clear all

local outdir "../../out"

* Load the estimation sample
use "../../dta/sample/main.dta", clear

keep if manuf == 1

foreach v in "ind_prodwemp_1991" "ind_capvadd_1991" "ind_lnavgw_1991" "ind_ci_1990" "ind_htsh1_1990" "d_ind_shemp_7691" "d_ind_lnavgw_7691" {
	* Compute summary statistics, weighting by industry size
	quietly sum `v' [aw = cbp_emp1991], detail

	local n = r(N)
	local mean = r(mean)
	local sd = r(sd)
	local min = r(min)
	local max = r(max)

	* Row of means, SDs, mins, maxes
	mat row1 = (`n', `mean', `sd', `min', `max')
	mat rownames row1 = `v'

	* Tack on to stats matrix
	capture confirm mat stats
	if _rc != 0 {
		mat stats = row1
	}
	else {
		mat stats = (stats \ row1)
	}
}

* Load a dataset of summary stats into memory
clear
svmat stats

* Add a column indicating variable names
local names: rownames stats

gen v = ""
order v

forvalues i = 1/`=_N' {
	local name: word `i' of `names'
	replace v = "`name'" in `i'
}

* Update the "raw data" sheet in the Excel file
export excel "`outdir'/AADHP-JOLE-Appendix.xlsx", sheetreplace sheet(AppTab1_Raw)

